@@ -488,7 +488,17 @@ class House(ObjectBase):
             description=''
         ),
         'house_type': FieldDescriptor(
-            data_type=_int,
+            data_type=_unicode_or_empty,
+            required=False,
+            description=''
+        ),
+        'building_type': FieldDescriptor(
+            data_type=_unicode_or_empty,
+            required=False,
+            description=''
+        ),
+        'structure_type': FieldDescriptor(
+            data_type=_unicode_or_empty,
             required=False,
             description=''
         ),
