@@ -13,11 +13,11 @@ from m3_ext.ui.fields.simple import ExtStringField
 from m3_ext.ui.fields.simple import ExtTextArea
 from m3_ext.ui.misc.store import ExtJsonStore
 
-from m3_gar_client.constants import UI_LEVEL_FLAT
-from m3_gar_client.constants import UI_LEVEL_HOUSE
-from m3_gar_client.constants import UI_LEVEL_PLACE
-from m3_gar_client.constants import UI_LEVEL_STREET
-from m3_gar_client.constants import UI_LEVELS
+from m3_gar_constants import UI_LEVEL_FLAT
+from m3_gar_constants import UI_LEVEL_HOUSE
+from m3_gar_constants import UI_LEVEL_PLACE
+from m3_gar_constants import UI_LEVEL_STREET
+from m3_gar_constants import UI_LEVELS
 from m3_gar_client.data import ObjectDictAdapter
 from m3_gar_client.data import ObjectMapper
 from m3_gar_client.utils import cached_property
@@ -60,6 +60,8 @@ class UIHouseMapper(ObjectMapper):
         'structureNumber': 'structure_number',
         'postalCode': 'postal_code',
         'houseType': 'house_type',
+        'buildingType': 'building_type',
+        'structureType': 'structure_type',
     }
 
 
@@ -103,6 +105,8 @@ class AddressFields(BaseExtComponent):
             'house_id': 'house_id',
             'flat_number': 'flat_number',
             'full_address': 'full_address',
+            'building_type': 'building_type',
+            'structure_type': 'structure_type',
         }
 
         # Подписи полей ввода.
@@ -111,8 +115,8 @@ class AddressFields(BaseExtComponent):
             'zip_code': 'Индекс',
             'street_name': 'Улица',
             'house_number': 'Дом (здание)',
-            'building_number': 'Корпус',
-            'structure_number': 'Строение',
+            'building_number': 'Корпус (Стр-ие)',
+            'structure_number': 'Доп.номер',
             'flat_number': 'Квартира',
             'full_address': 'Полный адрес',
         }
@@ -293,6 +297,8 @@ class AddressFields(BaseExtComponent):
                 'structureNumber',
                 'postalCode',
                 'houseType',
+                'buildingType',
+                'structureType',
             ],
             store=ExtJsonStore(
                 url=self.backend.house_search_url,
@@ -360,6 +366,30 @@ class AddressFields(BaseExtComponent):
             name=self._names_of_fields['house_type'],
         )
 
+    @cached_property
+    def field__building_type(self):
+        """
+        Поле для хранения типа корпуса
+
+        :rtype: m3_ext.ui.fields.simple.ExtHiddenField
+        """
+        return ExtHiddenField(
+            type=ExtHiddenField.STRING,
+            name=self._names_of_fields['building_type'],
+        )
+
+    @cached_property
+    def field__structure_type(self):
+        """
+        Поле для хранения типа строения
+
+        :rtype: m3_ext.ui.fields.simple.ExtHiddenField
+        """
+        return ExtHiddenField(
+            type=ExtHiddenField.STRING,
+            name=self._names_of_fields['structure_type'],
+        )
+
     @cached_property
     def field__flat_number(self):
         """Поле для ввода номера квартиры.
@@ -415,6 +445,8 @@ class AddressFields(BaseExtComponent):
                 self.field__house_type,
                 self.field__building_number,
                 self.field__structure_number,
+                self.field__building_type,
+                self.field__structure_type,
             ))
 
         if self.level == UI_LEVEL_FLAT:
@@ -504,6 +536,8 @@ class AddressFields(BaseExtComponent):
             put('structureNumberField', self.field__structure_number.render)
             put('houseIDField', self.field__house_id.render)
             put('houseTypeField', self.field__house_type.render)
+            put('buildingTypeField', self.field__building_type.render)
+            put('structureTypeField', self.field__structure_type.render)
 
             if self.house:
                 house_dict = ObjectDictAdapter(self.house)
@@ -578,8 +612,8 @@ class RowsAddressView(AddressViewBase):
             'zipCode': 44,
             'street': 110,
             'house': 28,
-            'building': 44,
-            'structure': 58,
+            'building': 95,
+            'structure': 60,
             'flat': 55,
             'fullAddress': 110,
         })
