@@ -2,8 +2,8 @@
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
-from m3_gar_client.constants import GAR_HIERARCHIES
-from m3_gar_client.constants import GAR_HIERARCHY_MUN
+from m3_gar_constants import GAR_HIERARCHIES
+from m3_gar_constants import GAR_HIERARCHY_MUN
 from m3_gar_client.data import AddressObject
 from m3_gar_client.data import House
 
